platformdirs: Small Python package for determining appropriate platform-specific dirs, e.g. a "user data dir"
=============================================================================================================

Description
-----------

Small Python package for determining appropriate platform-specific dirs, e.g. a "user data dir"

License
-------

Upstream Contact
----------------

https://pypi.org/project/platformdirs/

